import * as i0 from '@angular/core';
import { SecurityContext, Injectable, Component, NgModule } from '@angular/core';
import * as i1$1 from '@dynamic-forms/core';
import { DynamicFormElementBase, dynamicFormLibrary, DynamicFormConfigModule } from '@dynamic-forms/core';
import { BehaviorSubject, of } from 'rxjs';
import { map, switchMap } from 'rxjs/operators';
import { marked } from 'marked';
import * as i1 from '@angular/common/http';
import * as i2 from '@angular/platform-browser';
import * as i2$1 from '@angular/common';
import { CommonModule } from '@angular/common';

class DynamicFormMarkdownService {
    constructor(httpClient, sanitizer) {
        this.httpClient = httpClient;
        this.sanitizer = sanitizer;
        marked.setOptions({
            renderer: this.createRenderer(),
            headerIds: false,
        });
    }
    compile(markdown, options) {
        const securityContext = this.getSecurityContext(options);
        return this.sanitizer.sanitize(securityContext, this.parseMarkdown(markdown));
    }
    compileFromSource(source, options) {
        return this.httpClient.get(source, { responseType: 'text' }).pipe(map(markdown => this.compile(markdown, options)));
    }
    createRenderer() {
        const renderer = new marked.Renderer();
        renderer.link = (href, title, text) => {
            const link = marked.Renderer.prototype.link.call(renderer, href, title, text);
            return link.replace('<a', '<a target="_blank"');
        };
        return renderer;
    }
    parseMarkdown(markdown) {
        return marked.parse(markdown);
    }
    getSecurityContext(options) {
        return options && !options.sanitize ? SecurityContext.NONE : SecurityContext.HTML;
    }
}
DynamicFormMarkdownService.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "15.0.0", ngImport: i0, type: DynamicFormMarkdownService, deps: [{ token: i1.HttpClient }, { token: i2.DomSanitizer }], target: i0.ɵɵFactoryTarget.Injectable });
DynamicFormMarkdownService.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "15.0.0", ngImport: i0, type: DynamicFormMarkdownService });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "15.0.0", ngImport: i0, type: DynamicFormMarkdownService, decorators: [{
            type: Injectable
        }], ctorParameters: function () { return [{ type: i1.HttpClient }, { type: i2.DomSanitizer }]; } });

class DynamicFormMarkdownComponent extends DynamicFormElementBase {
    constructor(markdownService) {
        super();
        this.markdownService = markdownService;
    }
    ngOnInit() {
        this._markdownSubject = new BehaviorSubject({
            source: this.template.source,
            markdown: this.template.markdown,
        });
        this.markdown$ = this._markdownSubject.asObservable().pipe(switchMap(value => value.source
            ? this.markdownService.compileFromSource(value.source, this.definition.options)
            : of(this.markdownService.compile(value.markdown, this.definition.options))));
    }
    ngDoCheck() {
        const source = this.template.source;
        const markdown = this.template.markdown;
        if (this._markdownSubject.value.source !== source || this._markdownSubject.value.markdown !== markdown) {
            this._markdownSubject.next({ source, markdown });
        }
    }
}
DynamicFormMarkdownComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "15.0.0", ngImport: i0, type: DynamicFormMarkdownComponent, deps: [{ token: DynamicFormMarkdownService }], target: i0.ɵɵFactoryTarget.Component });
DynamicFormMarkdownComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "15.0.0", type: DynamicFormMarkdownComponent, selector: "dynamic-form-markdown", usesInheritance: true, ngImport: i0, template: "<div class=\"dynamic-form-markdown\" [ngClass]=\"template.className\" [innerHTML]=\"markdown$ | async\"></div>\n", dependencies: [{ kind: "directive", type: i2$1.NgClass, selector: "[ngClass]", inputs: ["class", "ngClass"] }, { kind: "pipe", type: i2$1.AsyncPipe, name: "async" }] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "15.0.0", ngImport: i0, type: DynamicFormMarkdownComponent, decorators: [{
            type: Component,
            args: [{ selector: 'dynamic-form-markdown', template: "<div class=\"dynamic-form-markdown\" [ngClass]=\"template.className\" [innerHTML]=\"markdown$ | async\"></div>\n" }]
        }], ctorParameters: function () { return [{ type: DynamicFormMarkdownService }]; } });

const dynamicFormMarkdownType = {
    type: 'markdown',
    component: DynamicFormMarkdownComponent,
    libraryName: dynamicFormLibrary.name,
};
class DynamicFormMarkdownModule {
}
DynamicFormMarkdownModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "15.0.0", ngImport: i0, type: DynamicFormMarkdownModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
DynamicFormMarkdownModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "15.0.0", ngImport: i0, type: DynamicFormMarkdownModule, declarations: [DynamicFormMarkdownComponent], imports: [CommonModule, i1$1.DynamicFormConfigModule], exports: [DynamicFormConfigModule,
        DynamicFormMarkdownComponent] });
DynamicFormMarkdownModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "15.0.0", ngImport: i0, type: DynamicFormMarkdownModule, providers: [
        DynamicFormMarkdownService,
    ], imports: [CommonModule,
        DynamicFormConfigModule.withElement(dynamicFormMarkdownType), DynamicFormConfigModule] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "15.0.0", ngImport: i0, type: DynamicFormMarkdownModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [
                        CommonModule,
                        DynamicFormConfigModule.withElement(dynamicFormMarkdownType),
                    ],
                    declarations: [
                        DynamicFormMarkdownComponent,
                    ],
                    exports: [
                        DynamicFormConfigModule,
                        DynamicFormMarkdownComponent,
                    ],
                    providers: [
                        DynamicFormMarkdownService,
                    ],
                }]
        }] });

/*
 * Public API Surface of markdown
 */

/**
 * Generated bundle index. Do not edit.
 */

export { DynamicFormMarkdownComponent, DynamicFormMarkdownModule, DynamicFormMarkdownService, dynamicFormMarkdownType };
//# sourceMappingURL=dynamic-forms-markdown.mjs.map
